import sys
import argparse
from model import Model

def box_generator(sx, sy, sz, hollow, color_index, no_roof, no_floor):
	print color_index
	if sx <= 0:
		print "Error! x should be > 0"
		return -1
	elif sy <= 0:
		print "Error! y should be > 0"
		return -1
	elif sz <= 0:
		print "Error! z should be > 0"
		return -1
	elif color_index < 0 or color_index > 255:
		print "Error! color index should be between 0 and 255"
		return -1

	# The program itself:
	model = Model(sx, sy, sz)
	model.offset_x = -sx/2
	model.offset_y = -sy/2

	for x in xrange(sx):
		for y in xrange(sy):
			for z in xrange(sz):
				if (x != 0 and x != sx-1) and (y != 0 and y != sy-1):
					if no_floor and z == 0:
						continue
					if no_roof and z == sz-1:
						continue
					if hollow and (z != 0 and z != sz-1):
						continue
				model.set_block(x, y, z, color_index)

	return model

def main():
	# Parse arguments:
	parser = argparse.ArgumentParser(description="Generates a box model and saves it to file.")
	parser.add_argument("filename", type=str, help="name of the resulting file")
	parser.add_argument("x", type=int, help="size of the box in x")
	parser.add_argument("y", type=int,help="size of the box in y")
	parser.add_argument("z", type=int, default=1, nargs="?",
		help="size of the box in z, default = 1")
	parser.add_argument("--color", dest="index", type=int, default=0,
		help="color index, between 0-255")
	parser.add_argument("--hollow", action="store_true",
		help="sets the box hollow")
	parser.add_argument("--nofloor", dest="no_floor", action="store_true",
		help="removes the floor")
	parser.add_argument("--noroof", dest="no_roof", action="store_true",
		help="removes the roof")
	args = parser.parse_args()

	model = box_generator(args.x, args.y, args.z, args.hollow, args.index,
		args.no_roof, args.no_floor)
	if model == -1:
		sys.exit(-1)

	with open(args.filename, "wb") as fp:
		model.save(fp)



if __name__ == '__main__':
	main()
