import sys
import argparse
from model import Model

def crop(original, fx, fy, fz, sx, sy, sz):
	# f: from
	# validate values
	if fx < 0 or sx < 0:
		print "Error! x should be >= 0"
		return -1
	elif fy < 0 or sy < 0:
		print "Error! y should be >= 0"
		return -1
	elif fz < 0 or sz < 0:
		print "Error! z should be >= 0"
		return -1

	old_x, old_y, old_z = original.get_size()
	# create new model
	new_model = Model(sx, sy, sz)
	# copy palette
	new_model.set_palette(original.get_palette())

	for x in xrange(sx):
		for y in xrange(sy):
			for z in xrange(sz):
				# get original color
				original_index = original.get_block(x+fx, y+fy, z+fz)
				# set the new color as the same
				new_model.set_block(x, y, z, original_index)

	return new_model

def main():
	# Parse arguments:
	parser = argparse.ArgumentParser(
		description="Crops the given area from model to a new model")
	parser.add_argument("input_file", type=str,
		help="name of the input file")
	parser.add_argument("output_file", type=str,
		help="name of the resulting file")
	parser.add_argument("x", type=int,
		help="starting x index")
	parser.add_argument("y", type=int,
		help="starting y index")
	parser.add_argument("z", type=int,
		help="starting z index")
	parser.add_argument("sx", type=int,
		help="x size of area")
	parser.add_argument("sy", type=int,
		help="y size of area")
	parser.add_argument("sz", type=int,
		help="z size of area")

	args = parser.parse_args()

	# Load original model
	old_model = Model()
	with open(args.input_file, "rb") as fp:
		old_model.load(fp)

	# Crop model
	new_model = crop(old_model, args.x, args.y, args.z, args.sx, args.sy, args.sz)
	if new_model == -1:
		sys.exit(-1)

	with open(args.output_file, "wb") as fp:
		new_model.save(fp)



if __name__ == '__main__':
	main()
