import sys
import argparse
from model import Model

def new_size(original, target, offset):
	if original > target:
		return original
	elif offset < 0:
		return -offset + target
	elif offset + original > target:
		return offset + original
	return target


def paste(original, target, fx, fy, fz, ignore_empty=False):
	# f: from

	old_x, old_y, old_z = original.get_size()
	target_x, target_y, target_z = target.get_size()
	new_x = new_size(old_x, target_x, fx)
	new_y = new_size(old_y, target_y, fy)
	new_z = new_size(old_z, target_z, fz)

	# copy the target model to possibly new position
	offset_x = -fx if fx < 0 else 0
	offset_y = -fy if fy < 0 else 0
	offset_z = -fz if fz < 0 else 0
	new_model = Model(new_x, new_y, new_z)
	new_model.set_palette(target.get_palette())
	new_model.set_offsets(*target.get_offsets())
	for x in xrange(target_x):
		for y in xrange(target_y):
			for z in xrange(target_z):
				original_index = target.get_block(x, y, z)
				new_model.set_block(x+offset_x, y+offset_y, z+offset_z, original_index)

	# paste the model
	offset_x = 0 if fx < 0 else fx
	offset_y = 0 if fy < 0 else fy
	offset_z = 0 if fz < 0 else fz
	for x in xrange(old_x):
		for y in xrange(old_y):
			for z in xrange(old_z):
				# get original color
				original_index = original.get_block(x, y, z)
				if ignore_empty:
					if original_index == Model.empty_index:
						continue
				# set the new color as the same
				new_model.set_block(x+offset_x, y+offset_y, z+offset_z, original_index)

	return new_model

def main():
	# Parse arguments:
	parser = argparse.ArgumentParser(
		description="Pastes a model to another model to the given position. Palette is taken from target file")
	parser.add_argument("input_file", type=str,
		help="name of the input file")
	parser.add_argument("target_file", type=str,
		help="name of the target file")
	parser.add_argument("output_file", type=str,
		help="name of the resulting file")
	parser.add_argument("x", type=int,
		help="starting x index")
	parser.add_argument("y", type=int,
		help="starting y index")
	parser.add_argument("z", type=int,
		help="starting z index")
	parser.add_argument("--ignore-empty","-i", dest="empty", action="store_true",
		help="if set, empty cells aren't pasted to output")
	args = parser.parse_args()

	# load original model
	old_model = Model()
	with open(args.input_file, "rb") as fp:
		old_model.load(fp)

	# load target model
	target_model = Model()
	with open(args.target_file, "rb") as fp:
		target_model.load(fp)

	# paste model
	new_model = paste(old_model, target_model, args.x, args.y, args.z, args.empty)
	if new_model == -1:
		sys.exit(-1)

	with open(args.output_file, "wb") as fp:
		new_model.save(fp)



if __name__ == '__main__':
	main()
