import sys
import argparse
from model import Model

def model_scaler(original, sx, sy=None, sz=None):
	# validate values
	if sy == None:
		sy = sx
	if sz == None:
		sz = sx
	if sx <= 0:
		print "Error! x should be > 0"
		return -1
	elif sy <= 0:
		print "Error! y should be > 0"
		return -1
	elif sz <= 0:
		print "Error! z should be > 0"
		return -1

	old_x, old_y, old_z = original.get_size()
	# calculate the size of new model
	new_x = old_x * sx
	new_y = old_y * sy
	new_z = old_z * sz
	# create new model
	new_model = Model(new_x, new_y, new_z)
	# set offsets
	new_model.offset_x = -new_x/2
	new_model.offset_y = -new_y/2
	# copy palette
	new_model.set_palette(original.get_palette())

	for x in xrange(old_x):
		for y in xrange(old_y):
			for z in xrange(old_z):
				# get original color
				original_index = original.get_block(x, y, z)
				for i in xrange(sx):
					for j in xrange(sy):
						for k in xrange(sz):
							# set the new color as the same
							new_model.set_block(x*sx+i, y*sy+j, z*sz+k, original_index)

	return new_model

def main():
	# Parse arguments:
	parser = argparse.ArgumentParser(
		description="Adds empty scale to the model for easier editing. scale is added to both directions.")
	parser.add_argument("input_file", type=str,
		help="name of the input file")
	parser.add_argument("output_file", type=str,
		help="name of the resulting file")
	parser.add_argument("x", type=input,
		help="scale to be added on x axis")
	parser.add_argument("y", type=int, nargs="?",
		help="scale to be added on y axis, defaults to x")
	parser.add_argument("z", type=int, nargs="?",
		help="scale to be added on z axis, defaults to x")
	args = parser.parse_args()

	# Load original model
	old_model = Model()
	with open(args.input_file, "rb") as fp:
		old_model.load(fp)

	# Add margin
	new_model = model_scaler(old_model, args.x, args.y, args.z)
	if new_model == -1:
		sys.exit(-1)

	with open(args.output_file, "wb") as fp:
		new_model.save(fp)



if __name__ == '__main__':
	main()
